@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,13 +12,11 @@
 #
 ##############################################################################
 """ZCML directives for defining browser pages
-
-$Id: metadirectives.py 103273 2009-08-27 14:15:45Z nadako $
 """
 from zope.interface import Interface
 from zope.configuration.fields import GlobalObject, GlobalInterface
-from zope.configuration.fields import Tokens, Path, PythonIdentifier, MessageID
-from zope.schema import TextLine, Id, Int, Bool
+from zope.configuration.fields import Path, PythonIdentifier, MessageID
+from zope.schema import TextLine
 from zope.security.zcml import Permission
 
 from zope.component.zcml import IBasicViewInformation
@@ -43,6 +41,13 @@ class IPagesDirective(IBasicViewInformation):
         required=False
         )
 
+    layer = GlobalObject(
+        title=u"The request interface or class this view is for.",
+        description=
+        u"Defaults to zope.publisher.interfaces.browser.IDefaultBrowserLayer.",
+        required=False
+        )
+
     permission = Permission(
         title=u"Permission",
         description=u"The permission needed to use the view.",
@@ -187,3 +192,20 @@ class IPageDirective(IPagesDirective, IPagesPageSubdirective):
     The page directive creates a new view class from a given template
     and/or class and registers it.
     """
+
+class IExpressionTypeDirective(Interface):
+    """Register a new TALES expression type"""
+
+    name = TextLine(
+        title=u"Name",
+        description=u"""Name of the expression. This will also be used
+        as the prefix in actual TALES expressions.""",
+        required=True
+        )
+
+    handler = GlobalObject(
+        title=u"Handler",
+        description=u"""Handler is class that implements
+        zope.tales.interfaces.ITALESExpression.""",
+        required=True
+        )
