@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005-2009 Zope Corporation and Contributors.
+# Copyright (c) 2005-2009 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """
-
-$Id: test_namedtemplate.py 106934 2009-12-22 21:35:55Z hannosch $
 """
 import os
 import os.path
@@ -30,8 +28,10 @@ def pageSetUp(test):
 
 
 def test_suite():
-    from zope.testing import doctest
+    import doctest
+    filename = os.path.join(os.pardir, 'namedtemplate.txt')
     return doctest.DocFileSuite(
-        os.path.join(os.pardir, 'namedtemplate.txt'),
+        filename,
         setUp=pageSetUp, tearDown=zope.component.testing.tearDown,
+        globs={'__file__':  os.path.abspath(os.path.join(os.path.dirname(__file__), filename))}
         )
