@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,17 +12,16 @@
 #
 ##############################################################################
 """Tests for browser:page directive and friends
-
-$Id: test_page.py 106891 2009-12-22 18:39:51Z hannosch $
 """
 
 import sys
 import os
 import unittest
+from doctest import DocTestSuite
 from cStringIO import StringIO
 
 from zope import component
-from zope.interface import Interface, implements, directlyProvides, providedBy
+from zope.interface import Interface, implementer, directlyProvides, providedBy
 
 import zope.security.management
 from zope.configuration.xmlconfig import xmlconfig, XMLConfig
@@ -35,7 +34,6 @@ from zope.publisher.interfaces.browser import IBrowserSkinType, IDefaultSkin
 from zope.security.proxy import removeSecurityProxy, ProxyFactory
 from zope.security.permission import Permission
 from zope.security.interfaces import IPermission
-from zope.testing.doctest import DocTestSuite
 from zope.testing import cleanup
 from zope.traversing.adapters import DefaultTraversable
 from zope.traversing.interfaces import ITraversable
@@ -76,8 +74,9 @@ class VT(V1, object):
         except:
             return super(VT, self).publishTraverse(request, name)
 
+@implementer(IC)
 class Ob(object):
-    implements(IC)
+    pass
 
 ob = Ob()
 
@@ -93,8 +92,8 @@ class CV(NCV):
         pass
 
 
+@implementer(Interface)
 class C_w_implements(NCV):
-    implements(Interface)
 
     def index(self):
         return self
@@ -267,9 +266,8 @@ class Test(cleanup.CleanUp, unittest.TestCase):
             '''
             <browser:page name="test"
                 class="zope.component.testfiles.views.VZMI"
-                layer="
-                  zope.browserpage.tests.test_page.ITestLayer"
                 for="zope.component.testfiles.views.IC"
+                layer="zope.browserpage.tests.test_page.ITestLayer"
                 permission="zope.Public"
                 attribute="index"
                 />
@@ -714,18 +712,17 @@ class Test(cleanup.CleanUp, unittest.TestCase):
         xmlconfig(StringIO(template %
             '''
             <browser:pages
-                for="*"
                 class="zope.component.testfiles.views.V1"
+                for="*"
                 permission="zope.Public"
                 >
               <browser:page name="index.html" attribute="index" />
             </browser:pages>
 
             <browser:pages
-                for="*"
                 class="zope.component.testfiles.views.V1"
-                layer="
-                  zope.browserpage.tests.test_page.ITestLayer"
+                for="*"
+                layer="zope.browserpage.tests.test_page.ITestLayer"
                 permission="zope.Public"
                 >
               <browser:page name="index.html" attribute="action" />
